import requests
from rich.console import Console
import sys
import os

console = Console()


def getdemonlist():
    console.print("Getting demonlist... Please wait.", style="bold red")
    top100_url = "https://pointercrate.com/api/v2/demons/listed/?limit=100"
    top100_to200_url = "https://pointercrate.com/api/v2/demons/listed/?limit=100&after=100"
    top200_to300_url = "https://pointercrate.com/api/v2/demons/listed/?limit=100&after=200"
    top300_to400_url = "https://pointercrate.com/api/v2/demons/listed/?limit=100&after=300"
    top400_tomax_url = "https://pointercrate.com/api/v2/demons/listed/?limit=100&after=400"
    response100 = requests.get(top100_url)
    response200 = requests.get(top100_to200_url)
    response300 = requests.get(top200_to300_url)
    response400 = requests.get(top300_to400_url)
    responsemax = requests.get(top400_tomax_url)
    demonsfinal = response100.json()+response200.json()+response300.json()+response400.json()+responsemax.json()

    if sys.platform == "win32":
        os.system("clear")
    else:
        os.system("clear")

    return demonsfinal


def menu(demonlist):
    console.print("Demonlist Search", style="bold red")
    console.print("1. Search by name")
    console.print("2. Search by position")
    console.print("3. Search by publisher")
    console.print("4. Search by verifier")
    console.print("5. Search by list requirement")
    console.print("6. Search by ID")
    console.print("7. Search by level ID")

    choice = input("Enter your choice: ")
    if choice == "1":
        namesearch(demonlist)
    elif choice == "2":
        possearch(demonlist)
    elif choice == "3":
        pubsearch(demonlist)
    elif choice == "4":
        versearch(demonlist)
    elif choice == "5":
        reqsearch(demonlist)
    elif choice == "6":
        idsearch(demonlist)
    elif choice == "7":
        levelSearch(demonlist)
    else:
        console.print("Invalid choice", style="bold red")
        menu(demonlist)


def namesearch(demons):
    found = False
    name = input("Enter demon name: ")
    for demon in demons:
        if name.lower() in demon["name"].lower():
            printDemon(demon)
            found = True
    if not found:
        console.print("Level not found", style="bold red")
    menu(demons)


def possearch(demons):
    found = False
    pos = input("Enter level position: ")
    try:
        if int(pos) > 447:
            console.print("Invalid position", style="bold red")
        else:
            for demon in demons:
                if demon["position"] == int(pos):
                    printDemon(demon)
                    found = True
            if not found:
                console.print("Demon not found", style="bold red")
    except ValueError:
        console.print("Invalid position", style="bold red")
    menu(demons)


def pubsearch(demons):
    found = False
    pub = input("Enter level publisher: ")
    for demon in demons:
        if pub.lower() in demon["publisher"]["name"].lower():
            printDemon(demon)
            found = True
    if not found:
        console.print("Level not found", style="bold red")
    menu(demons)


def versearch(demons):
    found = False
    ver = input("Enter level verifier: ")
    for demon in demons:
        if ver.lower() in demon["verifier"]["name"].lower():
            printDemon(demon)
            found = True
    if not found:
        console.print("Level not found", style="bold red")
    menu(demons)


def reqsearch(demons):
    found = False
    req = input("Enter list requirement: ")
    try:
        for demon in demons:
            if demon["requirement"] == int(req):
                printDemon(demon)
                found = True
        if not found:
            console.print("Level not found", style="bold red")
    except ValueError:
        console.print("Invalid requirement", style="bold red")
    menu(demons)


def idsearch(demons):
    found = False
    id = input("Enter demon ID: ")
    try:
        for demon in demons:
            if demon["id"] == int(id):
                printDemon(demon)
                found = True
        if not found:
            console.print("Level not found", style="bold red")
    except ValueError:
        console.print("Invalid ID", style="bold red")
    menu(demons)


def levelSearch(demons):
    found = False
    level = input("Enter demon level ID: ")
    try:
        for demon in demons:
            if demon["level"] == int(level):
                printDemon(demon)
                found = True
        if not found:
            console.print("Level not found", style="bold red")
    except ValueError:
        console.print("Invalid level ID", style="bold red")
    menu(demons)


def printDemon(demon):
    console.print("\n")
    console.print(f"Name: {demon['name']}", style="bold white")
    console.print(f"Position: {demon['position']}", style="bold red")
    console.print(f"Publisher: {demon['publisher']['name']}", style="bold green")
    console.print(f"Verifier: {demon['verifier']['name']}", style="#66FF00")

    if demon["position"] > 150:
        console.print(f"List Requirement: [strike]{demon['requirement']}[/strike] N/A (Legacy)", style="bold blue")
    elif demon['position'] <= 75 or demon['requirement'] == 100:
        console.print(f"List Requirement: {demon['requirement']}%", style="bold magenta")
    else:
        console.print(f"List Requirement: [strike]{demon['requirement']}[/strike] 100%", style="bold magenta")


    console.print(f"ID: {demon['id']}", style="#202020")
    console.print(f"Level ID: {demon['level_id']}", style="#202020")
    console.print(f"Video: {demon['video']}", style="bold blue")
    console.print(f"Thumbnail: {demon['thumbnail']}", style="bold purple")
    console.print("\n")


if __name__ == "__main__":
    demons = getdemonlist()
    menu(demons)



import requests
import random
from rich.console import Console

console = Console()
console.print("Welcome to the demonlist randomizer!", style="bold red")

def getDemonlist():
    TOP100URL = "https://pointercrate.com/api/v2/demons/listed/?limit=100"
    TOP100TO150URL = "https://pointercrate.com/api/v2/demons/listed/?after=100"
    response100 = requests.get(TOP100URL)
    response150 = requests.get(TOP100TO150URL)
    demons100 = response100.json()
    demons150 = response150.json()
    demons = demons100 + demons150
    return demons


def main():
    percent = 1
    demons = getDemonlist()
    demonnames = []
    for demon in demons:
        demonnames.append(demon["name"])

    while percent <= 100:
        i = random.randint(0, len(demonnames) - 1)
        stringpercent = str(percent) + "%"
        console.print(stringpercent+ f": {demonnames[i]}", style="bold cyan")
        del demonnames[i]

        percent += 1


if __name__ == "__main__":
    main()



import requests
import sys
import os


def getdemonlist():
    print("Getting demonlist... Please wait.")
    top100_url = "https://pointercrate.com/api/v2/demons/listed/?limit=100"
    top100_to200_url = "https://pointercrate.com/api/v2/demons/listed/?limit=100&after=100"
    top200_to300_url = "https://pointercrate.com/api/v2/demons/listed/?limit=100&after=200"
    top300_to400_url = "https://pointercrate.com/api/v2/demons/listed/?limit=100&after=300"
    top400_tomax_url = "https://pointercrate.com/api/v2/demons/listed/?limit=100&after=400"
    response100 = requests.get(top100_url)
    response200 = requests.get(top100_to200_url)
    response300 = requests.get(top200_to300_url)
    response400 = requests.get(top300_to400_url)
    responsemax = requests.get(top400_tomax_url)
    demonsfinal = response100.json()+response200.json()+response300.json()+response400.json()+responsemax.json()

    if sys.platform == "win32":
        os.system("clear")
    else:
        os.system("clear")

    return demonsfinal


def menu(demonlist):
    print("Demonlist Search")
    print("1. Search by name")
    print("2. Search by position")
    print("3. Search by publisher")
    print("4. Search by verifier")
    print("5. Search by list requirement")
    print("6. Search by ID")
    print("7. Search by level ID")

    choice = input("Enter your choice: ")
    if choice == "1":
        namesearch(demonlist)
    elif choice == "2":
        possearch(demonlist)
    elif choice == "3":
        pubsearch(demonlist)
    elif choice == "4":
        versearch(demonlist)
    elif choice == "5":
        reqsearch(demonlist)
    elif choice == "6":
        idsearch(demonlist)
    elif choice == "7":
        levelSearch(demonlist)
    else:
        print("Invalid choice")
        menu(demonlist)


def namesearch(demons):
    found = False
    name = input("Enter demon name: ")
    for demon in demons:
        if name.lower() in demon["name"].lower():
            printDemon(demon)
            found = True
    if not found:
        print("Level not found")
    menu(demons)


def possearch(demons):
    found = False
    pos = input("Enter level position: ")
    try:
        if int(pos) > 447:
            print("Invalid position")
        else:
            for demon in demons:
                if demon["position"] == int(pos):
                    printDemon(demon)
                    found = True
            if not found:
                print("Demon not found")
    except ValueError:
        print("Invalid position")
    menu(demons)


def pubsearch(demons):
    found = False
    pub = input("Enter level publisher: ")
    for demon in demons:
        if pub.lower() in demon["publisher"]["name"].lower():
            printDemon(demon)
            found = True
    if not found:
        print("Level not found")
    menu(demons)


def versearch(demons):
    found = False
    ver = input("Enter level verifier: ")
    for demon in demons:
        if ver.lower() in demon["verifier"]["name"].lower():
            printDemon(demon)
            found = True
    if not found:
        print("Level not found")
    menu(demons)


def reqsearch(demons):
    found = False
    req = input("Enter list requirement: ")
    try:
        for demon in demons:
            if demon["requirement"] == int(req):
                printDemon(demon)
                found = True
        if not found:
            print("Level not found")
    except ValueError:
        print("Invalid requirement")
    menu(demons)


def idsearch(demons):
    found = False
    id = input("Enter demon ID: ")
    try:
        for demon in demons:
            if demon["id"] == int(id):
                printDemon(demon)
                found = True
        if not found:
            print("Level not found")
    except ValueError:
        print("Invalid ID", style="bold red")
    menu(demons)


def levelSearch(demons):
    found = False
    level = input("Enter demon level ID: ")
    try:
        for demon in demons:
            if demon["level"] == int(level):
                printDemon(demon)
                found = True
        if not found:
            print("Level not found")
    except ValueError:
        print("Invalid level ID")
    menu(demons)


def printDemon(demon):
    print("\n")
    print(f"Name: {demon['name']}")
    print(f"Position: {demon['position']}")
    print(f"Publisher: {demon['publisher']['name']}")
    print(f"Verifier: {demon['verifier']['name']}")

    if demon["position"] > 150:
        print(f"List Requirement: N/A (Legacy)")
    elif demon['position'] <= 75 or demon['requirement'] == 100:
        print(f"List Requirement: {demon['requirement']}%")
    else:
        print(f"List Requirement: 100%")

    print(f"ID: {demon['id']}")
    print(f"Level ID: {demon['level_id']}")
    print(f"Video: {demon['video']}")
    print(f"Thumbnail: {demon['thumbnail']}")
    print("\n")


if __name__ == "__main__":
    demons = getdemonlist()
    menu(demons)



import requests
from rich.console import Console

console = Console()
limit = int(input("How many demons do you want to show: "))


def getDemonlist():
    TOP100URL = "https://pointercrate.com/api/v2/demons/listed/?limit=100"
    TOP100TO150URL = "https://pointercrate.com/api/v2/demons/listed/?after=100"
    response100 = requests.get(TOP100URL)
    response150 = requests.get(TOP100TO150URL)
    demons100 = response100.json()
    demons150 = response150.json()
    demons = demons100 + demons150
    return demons


def main():
    demons = getDemonlist()
    demonnames = []
    for i in range(limit):
        console.print(f"{i+1}: {demons[i]['name']}", style="bold cyan")



if __name__ == "__main__":
    main()



import requests
from rich.console import Console

console = Console()
listType = int(input("Show main (1) or extended (2): "))


def getDemonlistSize():
    demonlist = "https://pointercrate.com/api/v1/list_information"
    response = requests.get(demonlist)
    list = response.json()
    return list

if listType == 1:
    list = getDemonlistSize()
    console.print(f"Main demonlist size: {list['list_size']}", style="bold red")
elif listType == 2:
    list = getDemonlistSize()
    console.print(f"Extended demonlist size: {list['extended_list_size']}", style="bold red")
else:
    console.print("Invalid input!", style="bold red")



import requests
from rich.console import Console

console = Console()
console.print("Here you can find the current top players: ", style="bold red")

def getTopPlayers():
    playerLimit = int(input("How many players do you want to see (Max: 500): "))
    if playerLimit <= 100:
        TOP100URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100"
        response = requests.get(TOP100URL)
        players = response.json()
        return players, playerLimit
    elif playerLimit <= 200 and playerLimit > 100:
        TOP100URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100"
        TOP200URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100&after=100"
        response100 = requests.get(TOP100URL)
        response200 = requests.get(TOP200URL)
        players100 = response100.json()
        players200 = response200.json()
        players = players100 + players200
        return players, playerLimit
    elif playerLimit <= 300 and playerLimit > 200:
        TOP100URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100"
        TOP200URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100&after=100"
        TOP300URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100&after=200"
        response100 = requests.get(TOP100URL)
        response200 = requests.get(TOP200URL)
        response300 = requests.get(TOP300URL)
        players100 = response100.json()
        players200 = response200.json()
        players300 = response300.json()
        players = players100 + players200 + players300
        return players, playerLimit
    elif playerLimit <= 400 and playerLimit > 300:
        TOP100URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100"
        TOP200URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100&after=100"
        TOP300URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100&after=200"
        TOP400URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100&after=300"
        response100 = requests.get(TOP100URL)
        response200 = requests.get(TOP200URL)
        response300 = requests.get(TOP300URL)
        response400 = requests.get(TOP400URL)
        players100 = response100.json()
        players200 = response200.json()
        players300 = response300.json()
        players400 = response400.json()
        players = players100 + players200 + players300 + players400
        return players, playerLimit
    elif playerLimit <= 500 and playerLimit > 400:
        TOP100URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100"
        TOP200URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100&after=100"
        TOP300URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100&after=200"
        TOP400URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100&after=300"
        TOP500URL = "https://pointercrate.com/api/v1/players/ranking/?limit=100&after=400"
        response100 = requests.get(TOP100URL)
        response200 = requests.get(TOP200URL)
        response300 = requests.get(TOP300URL)
        response400 = requests.get(TOP400URL)
        response500 = requests.get(TOP500URL)
        players100 = response100.json()
        players200 = response200.json()
        players300 = response300.json()
        players400 = response400.json()
        players500 = response500.json()
        players = players100 + players200 + players300 + players400 + players500
        return players, playerLimit
    else:
        print("You can only see up to 500 players.")
        getTopPlayers()

def main():
    players, playerLimit = getTopPlayers()
    playerNames = []
    print("Top " + str(playerLimit) + " players:")
    for player in players:
        playerNames.append(player["name"])
    for i in range(playerLimit):
        print(str(i + 1) + ". " + playerNames[i])


if __name__ == "__main__":
    main()
